@@ -11,12 +11,21 @@ from zlib import crc32
 
 import oead
 from oead import aamp
-from oead.yaz0 import decompress # pylint: disable=import-error
+from oead.yaz0 import decompress  # pylint: disable=import-error
 import pymsyt
 from rstb import ResourceSizeTable
 from rstb.util import read_rstb
 
-from . import AAMP_EXTS, BYML_EXTS, SARC_EXTS, STOCK_FILES, get_canon_name
+from . import (
+    AAMP_EXTS,
+    BYML_EXTS,
+    SARC_EXTS,
+    STOCK_FILES,
+    get_canon_name,
+    NAMES,
+    RSTB_EXCLUDE_EXTS,
+    RSTB_EXCLUDE_NAMES,
+)
 
 HANDLED = {"ResourceSizeTable.product.srsizetable", "ActorInfo.product.sbyml"}
 
@@ -25,7 +34,9 @@ def _if_unyaz(data: bytes) -> bytes:
     return data if data[0:4] != b"Yaz0" else decompress(data)
 
 
-def _unbuild_file(f: Path, out: Path, content: str, mod: Path, verbose: bool) -> set:
+def _unbuild_file(
+    f: Path, out: Path, content: str, mod: Path, verbose: bool, skip_texts: bool = False
+) -> set:
     of = out / f.relative_to(mod)
     if not of.parent.exists():
         of.parent.mkdir(parents=True, exist_ok=True)
@@ -50,7 +61,7 @@ def _unbuild_file(f: Path, out: Path, content: str, mod: Path, verbose: bool) ->
         if "bactorpack" in f.suffix:
             names.update(_unbuild_actorpack(s, out / content))
         else:
-            names.update(_unbuild_sarc(s, of))
+            names.update(_unbuild_sarc(s, of, skip_texts=skip_texts))
         del s
     else:
         of.write_bytes(f.read_bytes())
@@ -61,7 +72,15 @@ def _unbuild_file(f: Path, out: Path, content: str, mod: Path, verbose: bool) ->
 
 def rstb_to_json(rstb: ResourceSizeTable, output: Path, names: set):
     hash_map = {crc32(h.encode("utf8")): h for h in STOCK_FILES}
-    hash_map.update({crc32(name.encode("utf8")): name for name in names})
+    found_names = {
+        crc32(name.encode("utf8")): name
+        for name in names
+        if name[name.rindex(".") :] not in RSTB_EXCLUDE_EXTS
+        and name not in RSTB_EXCLUDE_NAMES
+    }
+    hash_map.update(found_names)
+    saved_names = json.load(NAMES.open("r", encoding="utf-8")) if NAMES.exists() else {}
+    hash_map.update(saved_names)
 
     def hash_to_name(crc: int) -> str:
         return hash_map[crc] if crc in hash_map else str(crc)
@@ -75,10 +94,15 @@ def rstb_to_json(rstb: ResourceSizeTable, output: Path, names: set):
             },
             ensure_ascii=False,
             indent=2,
-            sort_keys=True
+            sort_keys=True,
         )
     )
 
+    NAMES.parent.mkdir(parents=True, exist_ok=True)
+    NAMES.write_text(
+        json.dumps({**found_names, **saved_names}, ensure_ascii=False), encoding="utf-8"
+    )
+
 
 def _unbuild_rstb(content: Path, be: bool, out: Path, mod: Path, names: set):
     f: Path = content / "System" / "Resource" / "ResourceSizeTable.product.srsizetable"
@@ -114,7 +138,9 @@ def _unbuild_actorpack(s: oead.Sarc, output: Path):
     return {f.name for f in s.get_files()}
 
 
-def _unbuild_sarc(s: oead.Sarc, output: Path, skip_actorpack: bool = False):
+def _unbuild_sarc(
+    s: oead.Sarc, output: Path, skip_actorpack: bool = False, skip_texts: bool = False
+):
     SKIP_SARCS = {
         "tera_resource.Cafe_Cafe_GX2.release.ssarc",
         "tera_resource.Nin_NX_NVN.release.ssarc",
@@ -134,7 +160,7 @@ def _unbuild_sarc(s: oead.Sarc, output: Path, skip_actorpack: bool = False):
         osf.parent.mkdir(parents=True, exist_ok=True)
         ext = osf.suffix
         if ext in SARC_EXTS:
-            if osf.name in SKIP_SARCS:
+            if osf.name in SKIP_SARCS or (osf.name.startswith("Msg_") and skip_texts):
                 osf.write_bytes(sarc_file.data)
                 continue
             try:
@@ -146,7 +172,7 @@ def _unbuild_sarc(s: oead.Sarc, output: Path, skip_actorpack: bool = False):
                 ):
                     names.update(_unbuild_actorpack(ss, output.parent.parent))
                 else:
-                    names.update(_unbuild_sarc(ss, osf))
+                    names.update(_unbuild_sarc(ss, osf, skip_texts=skip_texts))
                 del ss
             except ValueError:
                 osf.write_bytes(b"")
@@ -164,9 +190,9 @@ def _unbuild_sarc(s: oead.Sarc, output: Path, skip_actorpack: bool = False):
             osf.write_bytes(sarc_file.data)
 
     if "Msg_" in output.name:
-        pymsyt.export(output, output)
-        rmtree(output)
-        output.with_suffix("").rename(output)
+        pymsyt.export(str(output), str(output))
+        for file in output.rglob("**/*.msbt"):
+            file.unlink()
     if output.suffix in {".ssarc", ".sarc"}:
         (output / ".align").write_text(str(s.guess_min_alignment()))
     return names
@@ -221,6 +247,7 @@ def unbuild_mod(args) -> None:
                     content=content,
                     out=out,
                     verbose=args.verbose,
+                    skip_texts=args.no_texts,
                 ),
                 files,
             )
@@ -230,7 +257,7 @@ def unbuild_mod(args) -> None:
 
     try:
         (out / content / "Actor" / "Pack").rmdir()
-    except PermissionError:
+    except (PermissionError, OSError, FileNotFoundError):
         pass
 
     print("Unpacking actor info...")
